import { Column, ColumnType, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn } from "typeorm";
import { getTypeByORM } from "../../../migrations/ormHelper";
import { WearableType } from "./wearableType";
import { DamageReport } from "../damageReport";
import { member } from "../../club/member/member";

@Entity()
export class Wearable {
  @PrimaryGeneratedColumn("uuid")
  id: string;

  @Column({ type: "varchar", length: 255, nullable: true, unique: true })
  code?: string;

  @Column({ type: "varchar", length: 255 })
  name: string;

  @Column({ type: "varchar", length: 255 })
  location: string;

  @Column({ type: getTypeByORM("datetime").type as ColumnType })
  commissioned: Date;

  @Column({ type: getTypeByORM("datetime").type as ColumnType, nullable: true })
  decommissioned?: Date;

  @Column()
  equipmentTypeId: string;

  @Column()
  wearerId: string;

  @ManyToOne(() => WearableType, {
    nullable: false,
    onDelete: "RESTRICT",
    onUpdate: "RESTRICT",
  })
  wearableType: WearableType;

  @ManyToOne(() => member, {
    nullable: false,
    onDelete: "SET NULL",
    onUpdate: "RESTRICT",
  })
  wearer: member;

  @OneToMany(() => DamageReport, (d) => d.wearable, { cascade: ["insert"] })
  reports: DamageReport[];
}
