import { InspectionPointEnum } from "../../../../enums/inspectionEnum";
import type { EquipmentViewModel } from "../equipment/equipment.models";
import type { VehicleViewModel } from "../vehicle/vehicle.models";

export type PlanTimeDefinition = `${number}-${"d" | "m" | "y"}` | `${number}/${number | "*"}`;

export type InspectionPlanViewModel = {
  id: string;
  title: string;
  inspectionInterval: PlanTimeDefinition;
  remindTime: PlanTimeDefinition;
  version: number;
  created: Date;
  inspectionPoints: InspectionPointViewModel[];
  relatedId: string;
} & (
  | {
      assigned: "equipment";
      related: EquipmentViewModel;
    }
  | {
      assigned: "vehicle";
      related: VehicleViewModel;
    }
);

export interface InspectionVersionedPlanViewModel {
  id: string;
  version: number;
  created: Date;
  inspectionPoints: InspectionPointViewModel[];
}

export interface InspectionPointViewModel {
  id: string;
  title: string;
  description: string;
  type: InspectionPointEnum;
  min?: number;
}

export interface CreateInspectionPlanViewModel {
  title: string;
  inspectionInterval: PlanTimeDefinition;
  remindTime: PlanTimeDefinition;
  relatedId: string;
  assigned: "vehicle" | "equipment";
}

export interface UpdateInspectionPlanViewModel {
  id: string;
  title: string;
  inspectionInterval: PlanTimeDefinition;
  remindTime?: PlanTimeDefinition;
}
